Class: Browserctl::Migrations::Migration

Inherits:
Struct
  • Object
show all
Defined in:
lib/browserctl/migrations.rb

Overview

Single registered upgrader. ‘upgrade` is a Proc invoked with the absolute path of the file being migrated; it is responsible for rewriting that file in place, advancing it from `from_version` to `to_version`.

Instance Attribute Summary collapse

Instance Attribute Details

#formatObject

Returns the value of attribute format

Returns:

  • (Object)

    the current value of format



25
26
27
# File 'lib/browserctl/migrations.rb', line 25

def format
  @format
end

#from_versionObject

Returns the value of attribute from_version

Returns:

  • (Object)

    the current value of from_version



25
26
27
# File 'lib/browserctl/migrations.rb', line 25

def from_version
  @from_version
end

#to_versionObject

Returns the value of attribute to_version

Returns:

  • (Object)

    the current value of to_version



25
26
27
# File 'lib/browserctl/migrations.rb', line 25

def to_version
  @to_version
end

#upgradeObject

Returns the value of attribute upgrade

Returns:

  • (Object)

    the current value of upgrade



25
26
27
# File 'lib/browserctl/migrations.rb', line 25

def upgrade
  @upgrade
end