Class: Browserctl::Migrations::Result

Inherits:
Data
  • Object
show all
Defined in:
lib/browserctl/migrations.rb

Overview

Result of run. applied is the ordered list of Migration steps that ran. When the artifact was already at target, applied is empty.

Instance Attribute Summary collapse

Instance Attribute Details

#applied ⇒ Object (readonly)

Returns the value of attribute applied

Returns:

  • (Object) —

    the current value of applied



29
30
31
# File 'lib/browserctl/migrations.rb', line 29

def applied
  @applied
end

#format ⇒ Object (readonly)

Returns the value of attribute format

Returns:

  • (Object) —

    the current value of format



29
30
31
# File 'lib/browserctl/migrations.rb', line 29

def format
  @format
end

#from ⇒ Object (readonly)

Returns the value of attribute from

Returns:

  • (Object) —

    the current value of from



29
30
31
# File 'lib/browserctl/migrations.rb', line 29

def from
  @from
end

#to ⇒ Object (readonly)

Returns the value of attribute to

Returns:

  • (Object) —

    the current value of to



29
30
31
# File 'lib/browserctl/migrations.rb', line 29

def to
  @to
end