Class: Browserctl::Migrations::Migration
- Inherits:
-
Struct
- Object
- Struct
- Browserctl::Migrations::Migration
- Defined in:
- lib/browserctl/migrations.rb
Overview
Single registered upgrader. ‘upgrade` is a Proc invoked with the absolute path of the file being migrated; it is responsible for rewriting that file in place, advancing it from `from_version` to `to_version`.
Instance Attribute Summary collapse
-
#format ⇒ Object
Returns the value of attribute format.
-
#from_version ⇒ Object
Returns the value of attribute from_version.
-
#to_version ⇒ Object
Returns the value of attribute to_version.
-
#upgrade ⇒ Object
Returns the value of attribute upgrade.
Instance Attribute Details
#format ⇒ Object
Returns the value of attribute format
25 26 27 |
# File 'lib/browserctl/migrations.rb', line 25 def format @format end |
#from_version ⇒ Object
Returns the value of attribute from_version
25 26 27 |
# File 'lib/browserctl/migrations.rb', line 25 def from_version @from_version end |
#to_version ⇒ Object
Returns the value of attribute to_version
25 26 27 |
# File 'lib/browserctl/migrations.rb', line 25 def to_version @to_version end |
#upgrade ⇒ Object
Returns the value of attribute upgrade
25 26 27 |
# File 'lib/browserctl/migrations.rb', line 25 def upgrade @upgrade end |